@@ -1,8 +1,9 @@
 package Data::Predicate;
 
-our $VERSION = '2.0.0';
 use strict;
 use warnings;
+
+our $VERSION = '2.0.1';
 use Carp;
 
 sub new {
@@ -128,6 +129,11 @@ it but in the long run I think it is the right decision.
 
 =head1 METHODS
 
+=head2 new()
+
+Basic new method which does blessing of the current variable. Override & extend
+to bring your own slant to a predicate if required.
+
 =head2 apply()
 
 The core method; give it a reference and the apply method will return true
@@ -196,4 +202,4 @@ WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF 
 ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-=cut
\ No newline at end of file
+=cut
